# IRC settings
HOST = 'irc.freenode.net'
PORT = 6667
PASSWORD = None
NICKNAME = ''
REALNAME = ''
CHANNEL = ''

PLUGINS = ()

# Default settings for jeeves.core.plugins.ShortenerPlugin
SHORTENER_BACKEND = 'google'
SHORTENER_LOGIN = None
SHORTENER_API_KEY = None
